#!/bin/python
# -*- coding: utf-8 -*-

# Fenrir TTY screen reader
# By Chrys, Storm Dragon, and contributers.

import gettext
import locale

# the only function we really need to call here is gettext.install. Python3 has simplified this.
gettext.install("fenrir")
