#!/bin/python
# -*- coding: utf-8 -*-

# Fenrir TTY screen reader
# By Chrys, Storm Dragon, and contributers.

from fenrirscreenreader.core import debug

runtimeData = {
'speechDriver': None,
'screenDriver': None,
'soundDriver': None,
'inputDriver': None,
'remoteDriver': None,
'brailleDriver': None,
'inputManager': None,
'commandManager': None,
'screenManager': None,
'outputManager': None,
'debug':None,
}
